* -----------------------------------
* Project: APC modelling and covariates with application to obesity in England
* Script: gettinghsedata.do
* Last edited: 06/12/18
* Author: Zoe Fannon
* -----------------------------------
* This script takes raw HSE files 1991-2014 and combines them into a single 
* data set. It is based on a script from Higgins and Marshall (2012), 
* details of which below.


*Created by Vanessa Higgins and Alan Marshall, University of Manchester, April 2012
***This do file creates a single 1991-2009 HSE dataset containing a reduced version of each year of the Health Survey for England 1991-2009 (adult data only)
***There are 3 steps:
***Step 1 saving reduced and recoded datasets
*Opening a file
*Selecting appropriate variables
*Conducting the neccessary recoding
*Saving a reduced version of the file
***Step 2 - appending each year of the HSE to create a single 1991-2009 file
*Open the reduced version in 2009
*Append each years reduced HSE file
***Step 3 - deriving variables that are consistent over time for the years available
*Notes:
*No cluster variable before 2002. Cluster set to equal . for all years prior to 2002
*No sampling weight variable (wt_int) before 2003. Wt_int set to equal 1 for all years before 2003
*NB: if you wish to run this file you will need to download each year of the HSE data and save into a folder called to C:\Obesity Project|Data

* -----------------------------------

***** Setup ********

* directory in which raw data is stored and single dataset will be saved
cd "C:\Users\Zoe\Documents\Economics\DPhil_thesis\C1_BMI_indivWcovariates\replication\Data_modified"

*****Step 1 - saving reduced and recoded datasets************************

log using checkn
***Open 2014 data
clear
use "HSE_downloads\UKDA-7919-stata11_se\stata11_se\hse2014ai.dta", clear
display _N
*Select required variables
keep pserial psu wt_int topqual3 topqual2 origin2 tenureb eqvinc Sex ///
Age90 Wtval Htval BMIval Wstval hipval whval dnoft cigsta3 EndSmoke ///
cigst2 Cholest eqv5 gor1 EducEnd limlast SClass nssec3 nssec8
*Generate a year identifier variables
gen year=2014
*rename psu to area to match other years
rename psu area 
*Save reduced and recoded file
save "Reduced and recoded HSE files\2014.dta", replace
display _N

***Open 2013 data
clear
use "HSE_downloads\UKDA-7649-stata11_se\stata11_se\hse2013ai.dta", clear
display _N
*Select required variables
keep pserial PSU wt_int topqual3 topqual2 Origin tenureb eqvinc Sex ///
Age Wtval Htval BMIval Wstval hipval whval dnoft cigsta3 EndSmoke ///
cigst2 Cholest eqv5 gor1 EducEnd limlast SClass nssec3 nssec8
*Generate a year identifier variables
gen year=2013
*rename psu to area to match other years
rename PSU area
*Save reduced and recoded file
save "Reduced and recoded HSE files\2013.dta", replace
display _N

***Open 2012 data
clear
use "HSE_downloads\UKDA-7480-stata11_se\stata11_se\hse2012ai.dta", clear
display _N
*Select required variables
keep pserial PSU wt_int topqual3 topqual2 Origin tenureb eqvinc Sex ///
Age wtval htval bmival wstval hipval whval dnoft cigsta3 EndSmoke ///
cigst2 Cholest eqv5 gor1 EducEnd limlast SClass nssec3 nssec8
*Generate a year identifier variables
gen year=2012
*rename psu to area to match other years
rename PSU area
*Save reduced and recoded file
save "Reduced and recoded HSE files\2012.dta", replace
display _N

***Open 2011 data
clear
use "HSE_downloads\UKDA-7260-stata9_se\stata9_se\hse2011ai.dta", clear
display _N
*Select required variables
keep pserial PSU wt_int topqual3 topqual2 Origin tenureb eqvinc Sex ///
Age wtval htval bmival wstval hipval whval dnoft cigsta3 EndSmoke ///
cigst2 Cholest eqv5 gor1 EducEnd limitill 		 nssec3 nssec8
*Generate a year identifier variables
gen year=2011
*rename psu to area to match other years
rename PSU area
*Save reduced and recoded file
save "Reduced and recoded HSE files\2011.dta", replace
display _N

***Open 2010 data
clear
use "HSE_downloads\UKDA-6986-stata11\stata11\hse10ai.dta", clear
display _N
*Select required variables
keep pserial psu wt_int topqual3 topqual2 origin tenureb eqvinc sex ///
age wtval htval bmival wstval hipval whval dnoft cigsta3 startsmk endsmoke ///
cigst2 cholest eqv5 gor samptype educend limitill		 nssec3 nssec8
*Generate a year identifier variables
gen year=2010
*rename psu to area to match other years
rename psu area
* drop boost sample
drop if samptype==2
*changing gor from string to numeric variable
encode gor , generate (gorNEW)
drop gor
rename gorNEW gor
*Save reduced and recoded file
save "Reduced and recoded HSE files\2010.dta", replace
display _N

***Open 2009 data
clear
use "HSE_downloads\UKDA-6732-stata11\stata11\hse09ai.dta", clear
display _N
*Select required variables
keep pserial psu wt_int topqual3 topqual2 limitill origin tenureb eqvinc sex ///
age sclass wtval htval bmival wstval hipval whval dnoft cigsta3 startsmk endsmoke ///
cot15val cigst2 dinadias didiaval dinasyst disysval hdlval cholest eqv5 GOR ///
samptype educend nssec3 nssec8
*Generate a year identifier variables
gen year=2009
*rename psu to area to match other years
rename psu area
* drop boost sample
drop if samptype==2
*changing gor from string to numeric variable
encode GOR , generate (gorNEW)
drop GOR
rename gorNEW gor
*Save reduced and recoded file
save "Reduced and recoded HSE files\2009.dta", replace
display _N

***Open 2008 data
clear
use "HSE_downloads\UKDA-6397-stata11_se\stata11_se\hse08ai.dta", clear
display _N
*Select required variables
keep pserial psu wt_int topqual3 topqual2 limitill origin tenureb eqvinc sex ///
age sclass wtval htval bmival wstval hipval whval dnoft cigsta3 startsmk endsmoke ///
cot15val cigst2 dinadias didiaval dinasyst disysval hdlval cholest a30t06g eqv5 GOR ///
actphy oactq active hvyhwkhm a30t06g samptype educend nssec3 nssec8
*Generate a year identifier variables
gen year=2008
* drop boost sample
drop if samptype==2
*Save reduced and recoded file
save "Reduced and recoded HSE files\2008.dta", replace
display _N

***Open 2007 data
clear
use "HSE_downloads\UKDA-6112-stata8_se\stata8_se\hse07ai.dta", clear
display _N
*Select required variables
keep pserial area wt_int topqual3 topqual2 limitill ethinda tenureb eqvinc ///
sex age sclass wtval htval bmival wstval hipval whval dnoft cigsta3 startsmk endsmoke ///
cot15val cigst2 dinadias didiaval dinasyst disysval eqv5 gor07 samptype ///
educend nssec3 nssec8
*Generate a year identifier variables
gen year=2007
* drop boost sample
drop if samptype==2
*Save reduced and recoded file
save "Reduced and recoded HSE files\2007.dta", replace
display _N

***Open 2006 data
clear
use "HSE_downloads\UKDA-5809-stata8\stata8\hse06ai.dta", clear
display _N
*Select required variables
keep pserial psu wt_int topqual3 topqual2 limitill ethinda tenureb eqvinc sex ///
age sclass wtval htval bmival wstval hipval whval dnoft cigsta3 startsmk endsmoke ///
cot15val cigst2 dinadias didiaval dinasyst disysval hdlval cholest a30t06g eqv5 gor06 ///
oactq16 hevyhwrk a30t06g samptype educend nssec3 nssec8
*Generate a year identifier variables
gen year=2006
* drop boost sample
drop if samptype==3
*Save reduced and recoded file
save "Reduced and recoded HSE files\2006.dta", replace
display _N

***Open 2005 data
clear
use "HSE_downloads\UKDA-5675-stata8\stata8\hse05ai.dta", clear
display _N
*Select required variables
keep pserial area wt_int topqual3 topqual2 limitill ethinda tenureb eqvinc ///
sex age sclass wtval htval bmival wstval hipval whval dnoft cigsta3 startsmk endsmoke ///
cot15val cigst2 dinadias didiaval dinasyst disysval hdlval cholest samptype eqv5 gor ///
corgs07 corgs08 corgs09 corgs10 corgs11 corgs12 corgs13 ctrust cadvntg educend nssec3 nssec8
*Generate a year identifier variables
gen year=2005
*Drop boosted older person sample in 2005
drop if samptype==2
*Save reduced and recoded file
save "Reduced and recoded HSE files\2005.dta", replace
display _N

***Open 2004 data
clear
use "HSE_downloads\UKDA-5439-stata9\stata9\hse04gpa.dta", clear
display _N
*Select required variables
keep pserial area wt_int topqual3 topqual2 limitill ethcind tenureb eqvinc ///
sex age sclass wtval htval bmival wstval hipval whval dnoft cigsta3 startsmk endsmoke ///
cot15val cigst2 dinadias didiaval dinasyst disysval hdlval fldlval cholest adt30gp ///
eqvpop3 gor educend nssec3 nssec8
*dividing wt_int by its mean so it has a mean of 1 (like all other years)
summ wt_int
gen wt_inttemp=wt_int/14.15606		// this value is the mean
drop wt_int
rename wt_inttemp wt_int
summ wt_int
*Generate a year identifier variables
gen year=2004
*Save reduced and recoded file
save "Reduced and recoded HSE files\2004.dta", replace
display _N

***2003
clear
use "HSE_downloads\UKDA-5098-stata8\stata8\hse03ai.dta", clear
display _N
*Select required variables
keep pserial area int_wt topqual3 topqual2 limitill ethnici tenureb eqvinc ///
sex age sclass wtval htval bmival wstval hipval whval dnoft cigsta3 startsmk endsmoke ///
cot15val cigst2 dinadias didiaval dinasyst disysval hdlval fldlval cholest adt30gp ///
eqv5 gor samptype educend nssec3 nssec8
*rename int_wt to be consistent with previous years
rename int_wt wt_int
*Generate a year identifier variables
gen year=2003
*Save reduced and recoded file
save "Reduced and recoded HSE files\2003.dta", replace
display _N

***2002
clear
use "HSE_downloads\UKDA-4912-stata8_se\stata8_se\hse02ai.dta", clear
display _N
*Select required variables
keep pserial area topqual3 topqual2 limitill ethnici tenureb eqvinc sex age sclass ///
wtval htval bmival wstval hipval whval dnoft cigsta3 startsmk endsmoke cot15val ///
cigst2 newdiast diaval newsyst sysval adt30gp tablewt samptype eqv5 gor liveyrs ///
educend nssec3 nssec8
*Generate a year identifier variables
gen year=2002
*Drop boosted chidren/youngpeople/mother sample in 2002
drop if samptype==1
*Generate weight=1 for all cases in 2002 as we're dropping the boost so not relevant
gen wt_int=1
*gen wt_int=tablewt
*changing gor from string to numeric variable
encode gor , generate (gorNEW)
drop gor
rename gorNEW gor
*Save reduced and recoded file
save "Reduced and recoded HSE files\2002.dta", replace
display _N

***2001
clear
use "HSE_downloads\UKDA-4628-stata8\stata8\hse01ai.dta", clear
display _N
*Select required variables
keep pserial area topqual3 topqual2 limitill ethnici tenureb eqvinc sex age sclass ///
wtval htval bmival wstval hipval whval dnoft cigsta3 startsmk endsmoke cot15val ///
cigst2 newdiast diaval newsyst sysval eqv5 gora liveyrs livemths enjoy neigbrs ///
educend nssec3 nssec8
*Generate a year identifier variables
gen year=2001
*No wt_int (sampling weights) variable before 2003. Generate a weight variable 
* and set to equal 1. We need same varaibles in each file to append them.
gen wt_int=1
*changing gora from string to numeric variable
encode gora , generate (gorNEW)
drop gora
rename gorNEW gora
*No cluster variable before 2002. Creat a cluster variable for appending purposes
gen cluster=.
*Save reduced and recoded file
save "Reduced and recoded HSE files\2001.dta", replace
display _N

***2000
clear
use "HSE_downloads\UKDA-4487-stata8\stata8\hse00ai.dta", clear
display _N
*Select required variables
keep pserial area topqual3 topqual2 limitill ethnici tenureb eqvinc sex age sclass ///
wtval htval bmival wstval hipval whval dnoft cigsta3 startsmk endsmoke cot15val ///
cigst2 newdiast diaval newsyst sysval hdlval cholest samptype eqv5 gor educend
*Generate a year identifier variables
gen year=2000
*Drop boosted older person sample in 2000
drop if samptype==1
*No wt_int (sampling weights) variable before 2003. Generate a weight variable 
* and set to equal 1. We need same varaibles in each file to append them.
gen wt_int=1
*No cluster variable before 2002. Creat a cluster variable for appending purposes
gen cluster=.
*Save reduced and recoded file
save "Reduced and recoded HSE files\2000.dta", replace
display _N

***1999
clear
use "HSE_downloads\UKDA-4365-stata8\stata8\hse99gp3.dta", clear
display _N
*Select required variables
keep pserial area topqual3 topqual2 limitill ethnici tenureb eqvinc sex age sclass ///
wtval htval bmival wstval hipval whval dnoft cigsta3 startsmk endsmoke cot15val ///
cigst2 newdiast diaval newsyst sysval hdlval fldlval cholest adt30gp eqvpop3 gor ///
actphy oactq1 oactq2 oactq3 oactq4 active hevyhwrk adt30gp educend
*Generate a year identifier variables
gen year=1999
*No wt_int (sampling weights) variable before 2003. Generate a weight variable 
* and set to equal 1. We need same varaibles in each file to append them.
gen wt_int=1
*No cluster variable before 2002. Creat a cluster variable for appending purposes
gen cluster=.
*Save reduced and recoded file
save "Reduced and recoded HSE files\1999.dta", replace
display _N

***1998
clear
use "HSE_downloads\UKDA-4150-stata8\stata8\hse98ai.dta", clear
display _N
*Select required variables
keep pserial area topqual3 topqual2 limitill nethnic tenureb eqvinc sex age sclass ///
wtval htval bmival wstval hipval whval dnoft startsmk endsmoke cot15val cigst2 cigst1 ///
newdiast diaval newsyst sysval hdlval cholest adt30gp eqv5 gor actphy oactq1 oactq2 ///
oactq3 oactq4 active hevyhwrk adt30gp educend
*Generate a year identifier variables
gen year=1998
*No wt_int (sampling weights) variable before 2003. Generate a weight variable and 
* set to equal 1. We need same varaibles in each file to append them.
gen wt_int=1
*No cluster variable before 2002. Creat a cluster variable for appending purposes
gen cluster=.
*Save reduced and recoded file
save "Reduced and recoded HSE files\1998.dta", replace
display _N

***1997
clear
use "HSE_downloads\UKDA-3979-stata8\stata8\hse97ai.dta", clear
display _N
*Select required variables
keep pserial area topqual3 topqual2 limitill ethnic tenure eqvinc sex age sclass ///
wtval htval bmival wstval hipval whval dnoft startsmk endsmoke cot15val cigst1 cigst2 ///
newdiast diaval newsyst sysval tablewt samtyp eqv5 actphys oactq1 oactq2 oactq3 ///
oactq4 active hevyhwrk educend
*Generate a year identifier variables
gen year=1997
*No wt_int (sampling weights) variable before 2003. Generate a weight variable 
* and set to equal 1. We need same varaibles in each file to append them.
gen wt_int=tablewt
*No cluster variable before 2002. Creat a cluster variable for appending purposes
gen cluster=.
*Save reduced and recoded file
save "Reduced and recoded HSE files\1997.dta", replace
display _N

***1996
clear
use "HSE_downloads\UKDA-3886-stata8\stata8\hse96bind.dta", clear
display _N
*Select required variables
keep pserial area quala1 quala2 quala3 quala4 quala5 quala6 quala7 quala8 quala9 ///
quala10 limitill ethnic ownorent sex age sclass weight wtok height htok bmi bmiok ///
ddrinkof cigsmk2 startsmk endsmoke cotexnic newsmok2 newdiast diabp2 newsyst sysbp2 ///
educend 
*included cigsmk2 in case we decide we need to use it
*Generate a year identifier variables
gen year=1996
*No wt_int (sampling weights) variable before 2003. Generate a weight variable
* and set to equal 1. We need same varaibles in each file to append them.
gen wt_int=1
*No cluster variable before 2002. Creat a cluster variable for appending purposes
gen cluster=.
*No equivalise household income before 1996
gen eqvinc=.
gen eqv5=.
*Save reduced and recoded file
save "Reduced and recoded HSE files\1996.dta", replace
display _N

***1995
clear
use "HSE_downloads\UKDA-3796-stata8\stata8\hse95ai2nd.dta", clear
display _N
*Select required variables
keep pserial area sex age quala1 quala2 quala3 quala4 quala5 quala6 quala7 quala8 ///
quala9 quala10 bmi bmiok weight wtok height htok cigsmk2 startsmk endsmoke newsmok ///
ethnic educend ddrinkof longill sclass
*waist and hip - no waist or hip variables in 1995
*included cigsmk2 in case we decide we need to use it
*Generate a year identifier variables
gen year=1995
*No wt_int (sampling weights) variable before 2003. Generate a weight variable 
*and set to equal 1. We need same varaibles in each file to append them.
gen wt_int=1
*No cluster variable before 2002. Creat a cluster variable for appending purposes
gen cluster=.
*No equivalise household income before 1996
gen eqvinc=.
gen eqv5=.
*Save reduced and recoded file
save "Reduced and recoded HSE files\1995.dta", replace
display _N

***1994
clear
use "HSE_downloads\UKDA-3640-stata8\stata8\hse94ai2nd.dta", clear
display _N
*Select required variables
keep pserial area sex age bmi bmiok weight wtok height htok newsmok allwaist allhip ///
alwhipra hipok wstok whok topqual2 topqual3 actany acta actb actc actd active ///
hevyhwrk ethnic educend ddrinkof longill sclass cholest
*startsmk and endsmk and cigsmk2 not in 1994
*Generate a year identifier variables
gen year=1994
*No wt_int (sampling weights) variable before 2003. Generate a weight variable
* and set to equal 1. We need same varaibles in each file to append them.
gen wt_int=1
*No cluster variable before 2002. Creat a cluster variable for appending purposes
gen cluster=.
*No equivalise household income before 1996
gen eqvinc=.
gen eqv5=.
*Save reduced and recoded file
save "Reduced and recoded HSE files\1994.dta", replace
display _N

***1993
clear
use "HSE_downloads\UKDA-3316-stata8\stata8\3316.dta", clear
display _N
*Select required variables
keep hserno area sex age bmi bmiok weight wtok height htok cigsmk2 endsmoke cigsmk1 ///
year schedtyp allwaist allhip alwhipra hipok wstok whok topqual2 topqual3 actany acta ///
actb actc actd active hevyhwrk ethnic educend ddrinkof longill scall scstud
*startsmk not in 1994 so included cigsmk2
*Generate a year identifier variables
gen year1=year
drop year
gen year=1993
*No wt_int (sampling weights) variable before 2003. Generate a weight variable 
* and set to equal 1. We need same varaibles in each file to append them.
gen wt_int=1
*Drop non responders - these are included in 1993 (but not any other years)
drop if schedtyp==0
drop schedtyp
*rename hserno pserial - consistent with other years
rename hserno pserial
*No cluster variable before 2002. Creat a cluster variable for appending purposes
gen cluster=.
*No equivalise household income before 1996
gen eqvinc=.
gen eqv5=.
*Save reduced and recoded file
save "Reduced and recoded HSE files\1993.dta", replace
display _N

***1991/2
clear
use "HSE_downloads\UKDA-3238-stata8\stata8\3238", clear
display _N
*Select required variables
keep hserno area sex age weight wtok height htok bmi bmiok cigsmk2 endsmoke cigsmk1 ///
year waistav hipav whiprat whok topqual2 actany acta actb actc actd active hevyhwrk ///
ethnic educend ddrinkof longill soclase soclasst
*startsmk not in 1991-2 so included cigsmk2
*Generate a year identifier variables
gen year1=year
drop year
gen year=1992
*No wt_int (sampling weights) variable before 2003. Generate a weight variable 
* and set to equal 1. We need same varaibles in each file to append them.
gen wt_int=1
*rename hserno pserial - consistent with other years
rename hserno pserial
*No cluster variable before 2002. Creat a cluster variable for appending purposes
gen cluster=.
*No equivalise household income before 1996
gen eqvinc=.
gen eqv5=.
*Save reduced and recoded file
save "Reduced and recoded HSE files\1991-92.dta", replace
display _N

***********************************Step 2 - appending each year of the HSE to create one dataset for 1991-2014*************************
use "Reduced and recoded HSE files\2014.dta"
append using "Reduced and recoded HSE files\2013.dta"
append using "Reduced and recoded HSE files\2012.dta"
append using "Reduced and recoded HSE files\2011.dta"
append using "Reduced and recoded HSE files\2010.dta"
append using "Reduced and recoded HSE files\2009.dta"
append using "Reduced and recoded HSE files\2008.dta"
append using "Reduced and recoded HSE files\2007.dta"
append using "Reduced and recoded HSE files\2006.dta"
append using "Reduced and recoded HSE files\2005.dta"
append using "Reduced and recoded HSE files\2004.dta"
append using "Reduced and recoded HSE files\2003.dta"
append using "Reduced and recoded HSE files\2002.dta"
append using "Reduced and recoded HSE files\2001.dta"
append using "Reduced and recoded HSE files\2000.dta"
append using "Reduced and recoded HSE files\1999.dta"
append using "Reduced and recoded HSE files\1998.dta"
append using "Reduced and recoded HSE files\1997.dta"
append using "Reduced and recoded HSE files\1996.dta"
append using "Reduced and recoded HSE files\1995.dta"
append using "Reduced and recoded HSE files\1994.dta"
append using "Reduced and recoded HSE files\1993.dta"
append using "Reduced and recoded HSE files\1991-92.dta"

save "Reduced and recoded HSE files\1991_2014HSE.dta", replace

log close

********Step 3 - creating derived variables*************************

use "Reduced and recoded HSE files\1991_2014HSE.dta", clear

* Harmonize sex/Sex
replace sex=Sex if sex==.
drop Sex

* Harmonize age/Age/Age90
replace age=Age if age==.
replace age=Age90 if age==.
drop Age Age90
* drop age>=90 because of top-censoring at 90
drop if age>=90
*drop all children (<16 years)
drop if age<16

**Creating harmonised variables from 1991-2014 for BMI, weight, height, smoking, waist and hip**
**BMI
gen bmivalid=bmival if year>=1997
replace bmivalid=bmi if bmiok==1 & year<=1996
replace bmivalid=BMIval if year>=2013
codebook bmivalid
mvdecode bmivalid, mv (-1=.)
codebook bmivalid
drop bmival bmi bmiok BMIval

**Weight
gen wtvalid=wtval if year>=1997
replace wtvalid=weight if wtok==1 & year<=1996
replace wtvalid=Wtval if year>=2013
codebook wtvalid
mvdecode wtvalid, mv (-1=.)
codebook wtvalid
drop wtval weight wtok Wtval

**Height
gen htvalid=htval if year>=1997
replace htvalid=height if htok==1 & year<=1996
replace htvalid=Htval if year>=2013
codebook htvalid
mvdecode htvalid, mv (-8=.\-1=.)
codebook htvalid
*change 1994 height to cms
replace htvalid=htvalid*100 if year==1994
drop htval height htok Htval

**smoking status
gen 	byte smokeVH =newsmok if year==1994
recode 	smokeVH 7/11=1 2/6=2 1=3 *=.
gen 	byte smoke=cigsta3   if year>=1999
replace smoke = cigsmk2 if year==1996 | year==1995 | year==1993 | year==1992
gen 	byte smokeAM=cigst1 if year==1997|year==1998
recode 	smokeAM 4=1 2/3=2 1=3
replace smoke=smokeAM if year==1997|year==1998
replace smoke=smokeVH if year==1994
mvdecode smoke, mv (-9=.\-8=.\-7=.\-6=.\-2=.\-1=.)
label define smoke 1 "current" 2 "ex-regular" 3 "never regular"
label values smoke smoke
* ignore smoking quantity variables (for now)
drop EndSmoke cigsmk1 cigsmk2 cigst1 cigst2 cigsta3 endsmoke newsmok newsmok2 smokeAM smokeVH startsmk

*waist
gen waistvalid=wstval if year>=1997
* no waist measurements for 1995 or 1996
replace waistvalid=. if year==1995 | year==1996
replace waistvalid=allwaist if wstok==1 & (year==1993 | year==1994)
replace waistvalid=waistav if year==1992
replace waistvalid=Wstval if year>=2013
codebook waistvalid
mvdecode waistvalid, mv (-1=.\-9=.\-8=.\-7=.)
codebook waistvalid
*1992 doesn't have a wstok variable (it has a whok variable but this is whether whris ok not just waist ok)
drop wstval allwaist wstok waistav Wstval

*hip
gen hipvalid=hipval if year>=1997
* no hip measurements for 1995 or 1996
replace hipvalid=. if year==1995 | year==1996
replace hipvalid=allhip if hipok==1 & (year==1993 | year==1994)
replace hipvalid=hipav if year==1992
codebook hipvalid
mvdecode hipvalid, mv (-1=.\-9=.\-8=.\-7=. \999=.)	// 999 added as mv
codebook hipvalid
*1992 doesn't have a hipok variable (it has a whok variable but this is whether whr is ok not just hip ok)
drop hipval allhip hipok hipav

*wasit-hip ratio
gen WHR=whval if year>=1997
* no WHR for 1995 or 1996
replace WHR=. if year==1995 | year==1996
replace WHR=alwhipra if whok==1 & (year==1993 | year==1994)
replace WHR=whiprat if whok==1 & year==1992
codebook WHR
mvdecode WHR, mv (-1=.\-9=.\-8=.\-7=.)
codebook WHR
drop whval alwhipra whok whiprat


******************setting missing values******************

* Social Class
* adding early years
replace sclass=scall if year==1993
replace sclass=soclase if year==1992
* adding later years
recode SClass 5=6 4=5 3.2=4 3.1=3
replace sclass=SClass if year == 2012 | year == 2013 | year == 2014
**setting social class missing values to missing
mvdecode sclass, mv (-9=.\-8=.\-7=.\-1=.\0=.)
**recoding armed forces and 'not fully described as missing' (not clear where to put armed forces and only a handful of cases)
mvdecode sclass, mv (7=.\8=.)
** add student label for 9
label define sclass 9 "full time student", modify
label values sclass sclass
drop SClass soclase scall soclasst scstud

* nssec
* recode missing as missing
mvdecode nssec3, mv(-9=.\-1=.)
mvdecode nssec8, mv(-9=.\-1=.)

* Qualifications
**setting qualifiaction class missing values to missing
mvdecode topqual3, mv (-1=.\-9=.\-8=.\-7=.)
mvdecode topqual2, mv (-1=.\-9=.\-8=.\-7=.)

* Education
replace educend=EducEnd if year>2010
mvdecode educend, mv(-9=.\-8=.\-7=.\-1=.\9=.)
drop EducEnd

**setting tenureb missing values to missing
mvdecode tenureb, mv (-9=.\-8=.)

* Drinking
* add early years
replace dnoft=ddrinkof if year<=1996
**setting drinking missing values to missing
mvdecode dnoft, mv (-9=.\-8=.\-7=.\-6=.\-2=.\-1=.\9=.)
drop ddrinkof

* Limiting Ilness
replace limitill=limlast if year==2012 | year==2013 | year==2014
**setting limiting longstanding illness missing values to missing
mvdecode limitill, mv (-9=.\-8=.\-1=.)
* Long illness
gen longINT=limitill
recode longINT 2=1 3=2
replace longill=longINT if year>1995
mvdecode longill, mv(-8=.\-7=.\9=.)
drop limlast longINT

**setting equivalised income dv missing values to missing
mvdecode eqv5, mv (-1=.\-90=.)
mvdecode eqvinc, mv (-1=.\-90=.)

* combine Cholesterol variables
replace cholest=Cholest if cholest==.
mvdecode cholest, mv(-1=.\-2=.\9999=.)
drop Cholest

* drop unnecessary health info
drop diaval didiaval sysval disysval 
drop dinadias dinasyst diabp2 sysbp2 newdiast newsyst

*Ethnicity
gen byte ethgrp=origin2
label values ethgrp origin2
recode Origin 1/4=1 14/16=2 9/13=3 5/8=4 17/18=5
replace ethgrp=Origin if year==2011 | year==2012 | year==2013
recode origin 1/4=1 12/14=2 15=2 8/11=3 5/7=4 16=5
replace ethgrp=origin if year==2008 | year==2009 | year==2010
recode ethinda 2=92 4=94
recode ethinda 94=2 92=4
replace ethgrp=ethinda if year==2005 | year==2006 | year==2007
recode ethcind 2=92 3=93 4=94
recode ethcind 93=2 94=3 92=4
replace ethgrp=ethcind if year==2004
recode ethnici 2=92 3/4=93 5/6=95
recode ethnici 93=2 95=3 92=4 7=5
replace ethgrp=ethnici if year>= 1999 & year<=2003
recode nethnic 2/4=2 5/8=3 9=5
replace ethgrp=nethnic if year==1998
recode ethnic 2/4=2 5/10=3 11=4 12/14=5
replace ethgrp=ethnic if year<=1997
codebook ethgrp
mvdecode ethgrp, mv(-9=.\-8=.\-7=.\-1=.\0=.)
codebook ethgrp
drop origin2 Origin origin ethinda ethcind ethnici nethnic ethnic

******************value labels for gor over time (1998-2000 emids and wmids; 2006-07SW and SE******************
gen byte gornew06=gor06
recode gornew06 8=10 9=8
recode gornew06 10=9
ta gornew06
gen byte gornew07=gor07
recode gornew07 8=10 9=8
recode gornew07 10=9
ta gornew07
gen byte gornew9800=gor if year>=1998 & year<=2000
recode gornew9800 4=10 5=4
recode gornew9800 10=5
ta gornew9800
*creating gorVH over time
gen byte gorVH=gor if (year>=2002 & year<=2005) | (year>=2008 & year<=2010)
replace gorVH=gornew9800 if year>=1998 & year<=2000
replace gorVH=gora if year==2001
replace gorVH=gornew06 if year==2006
replace gorVH=gornew07 if year==2007
replace gorVH=GOR if year==2008
replace gorVH=gor1 if year>=2011
mvdecode gorVH, mv (10=.)
label define gorVH 1 "NE" 2 "NW" 3 "Yorks and Humberside" 4 "East Midlands" 5 "West Midlands" 6 "East England" 7 "London" 8 "SE" 9 "SW"
label values gorVH gorVH
drop gor1 gor GOR gor07 gor06 gora gornew06 gornew07 gornew9800

*******************creating obesity variable******************
gen byte bmigrp=bmivalid
replace bmigrp=1 if bmivalid >0 & bmivalid <18.5
replace bmigrp=2 if bmivalid >=18.5 & bmivalid <25
replace bmigrp=3 if bmivalid >=25 & bmivalid <30
replace bmigrp=4 if bmivalid>=30 & bmivalid <=75
label define bmigrp 1 "underweight" 2 "healthy weight" 3 "overweight" 4 "obese"
label values bmigrp bmigrp

*******************creating manual/non-manual variable******************
gen byte manual=sclass
replace manual=1 if sclass>=4 & sclass<=6
replace manual=2 if sclass>=1 & sclass<=3 | sclass==9
label define manual 1"manual" 2 "non-manual"
label values manual manual


* drop unnecessary sport variables
drop actany actphys actphy acta actb actc actd oactq1 oactq2 oactq3 oactq4 ///
oactq oactq16 

* drop other unnecessary variables
drop cot15val active hvyhwkhm a30t06g hevyhwrk corgs07 corgs08 corgs09 corgs10 ///
corgs11 corgs12 corgs13 ctrust cadvntg adt30gp liveyrs livemths enjoy neigbrs ///
quala1 quala2 quala3 quala4 quala5 quala6 quala7 quala8 quala9 quala10 ///
cotexnic hdlval fldlval tenureb tenure ownorent

******* variable labels
label variable smoke "Smoking status 1991-2014"
label variable year "Survey year"
label variable manual "manual/non manual worker"
label variable bmigrp "grouped BMI 1991-2014"
label variable bmivalid "BMI 1991-2014"
label variable gorVH "Government Office Regions 1998-2014"
label variable htvalid "Height 1991-2014"
label variable wtvalid "Weight 1991-2014"
label variable hipvalid "Hip 1991-2014"
label variable waistvalid "Waist 1991-2014"
label variable WHR "Waist-hip ratio 1991-2014"
label variable ethgrp "Ethnicity 1991-2014"

save "Reduced and recoded HSE files\1991_2014HSE.dta", replace
